@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
 import itertools
 import operator
 import re
 from collections.abc import Mapping, Set
-from functools import lru_cache, reduce
+from functools import reduce
 
 import attr
-import distlib.markers
-from packaging.markers import InvalidMarker, Marker
-from packaging.specifiers import LegacySpecifier, Specifier, SpecifierSet
-from packaging.version import parse
-from vistir.misc import dedup
+from distlib import markers
+from pip._vendor.packaging.markers import InvalidMarker, Marker
+from pip._vendor.packaging.specifiers import LegacySpecifier, Specifier, SpecifierSet
+from pip._vendor.packaging.version import parse
 
 from ..environment import MYPY_RUNNING
 from ..exceptions import RequirementError
@@ -117,7 +115,6 @@ class PipenvMarkers(object):
             return combined_marker
 
 
-@lru_cache(maxsize=1024)
 def _tuplize_version(version):
     # type: (STRING_TYPE) -> Union[Tuple[()], Tuple[int, ...], Tuple[int, int, str]]
     output = []
@@ -132,7 +129,6 @@ def _tuplize_version(version):
     return tuple(output)
 
 
-@lru_cache(maxsize=1024)
 def _format_version(version):
     # type: (Tuple[int, ...]) -> STRING_TYPE
     if not isinstance(version, str):
@@ -144,7 +140,6 @@ def _format_version(version):
 REPLACE_RANGES = {">": ">=", "<=": "<"}
 
 
-@lru_cache(maxsize=1024)
 def _format_pyspec(specifier):
     # type: (Union[STRING_TYPE, Specifier]) -> Specifier
     if isinstance(specifier, str):
@@ -180,7 +175,6 @@ def _format_pyspec(specifier):
     return specifier
 
 
-@lru_cache(maxsize=1024)
 def _get_specs(specset):
     if specset is None:
         return
@@ -264,7 +258,6 @@ def get_sorted_version_string(version_set):
 # TODO: Rename this to something meaningful
 # TODO: Add a deprecation decorator and deprecate this -- i'm sure it's used
 # in other libraries
-@lru_cache(maxsize=1024)
 def cleanup_pyspecs(specs, joiner="or"):
     specs = normalize_specifier_set(specs)
     # for != operator we want to group by version
@@ -298,7 +291,7 @@ def cleanup_pyspecs(specs, joiner="or"):
     for op_and_version_type, versions in _group_by_op(tuple(specs)):
         op = op_and_version_type[0]
         versions = [version[1] for version in versions]
-        versions = sorted(dedup(versions))
+        versions = sorted(dict.fromkeys(versions))  # remove duplicate entries
         op_key = next(iter(k for k in translation_keys if op in k), None)
         version_value = versions
         if op_key is not None:
@@ -310,7 +303,6 @@ def cleanup_pyspecs(specs, joiner="or"):
 
 
 # TODO: Rename this to something meaningful
-@lru_cache(maxsize=1024)
 def fix_version_tuple(version_tuple):
     # type: (Tuple[AnyStr, AnyStr]) -> Tuple[AnyStr, AnyStr]
     op, version = version_tuple
@@ -325,7 +317,6 @@ def fix_version_tuple(version_tuple):
 
 
 # TODO: Rename this to something meaningful, deprecate it (See prior function)
-@lru_cache(maxsize=128)
 def get_versions(specset, group_by_operator=True):
     # type: (Union[Set[Specifier], SpecifierSet], bool) -> List[Tuple[STRING_TYPE, STRING_TYPE]]
     specs = [_get_specs(x) for x in list(tuple(specset))]
@@ -485,7 +476,6 @@ def _markers_contains_key(markers, key):
     return False
 
 
-@lru_cache(maxsize=128)
 def get_contained_extras(marker):
     """Collect "extra == ..." operands from a marker.
 
@@ -499,7 +489,6 @@ def get_contained_extras(marker):
     return extras
 
 
-@lru_cache(maxsize=1024)
 def get_contained_pyversions(marker):
     """Collect all `python_version` operands from a marker."""
 
@@ -514,7 +503,7 @@ def get_contained_pyversions(marker):
         return set()
     # Use the distlib dictionary parser to create a dictionary 'trie' which is a bit
     # easier to reason about
-    marker_dict = distlib.markers.parse_marker(marker_str)[0]
+    marker_dict = markers.parse_marker(marker_str)[0]
     version_set = set()
     pyversions, _ = parse_marker_dict(marker_dict)
     if isinstance(pyversions, set):
@@ -530,7 +519,6 @@ def get_contained_pyversions(marker):
     return versions
 
 
-@lru_cache(maxsize=128)
 def contains_extra(marker):
     """Check whether a marker contains an "extra == ..." operand."""
     if not marker:
@@ -539,7 +527,6 @@ def contains_extra(marker):
     return _markers_contains_extra(marker._markers)
 
 
-@lru_cache(maxsize=128)
 def contains_pyversion(marker):
     """Check whether a marker contains a python_version operand."""
 
@@ -711,7 +698,6 @@ def normalize_marker_str(marker):
     return marker_str.replace('"', "'")
 
 
-@lru_cache(maxsize=1024)
 def marker_from_specifier(spec):
     # type: (STRING_TYPE) -> Marker
     if not any(spec.startswith(k) for k in Specifier._operators.keys()):
