@@ -1,4 +1,3 @@
-# -*- coding=utf-8 -*-
 import datetime
 import functools
 import io
@@ -12,16 +11,15 @@ from functools import reduce
 from typing import Sequence
 
 import attr
-import dateutil.parser
-import distlib.metadata
-import distlib.wheel
-import packaging.version
 import requests
 import vistir
-from packaging.markers import Marker
-from packaging.requirements import Requirement as PackagingRequirement
-from packaging.specifiers import Specifier, SpecifierSet
-from packaging.tags import Tag
+from distlib import wheel
+from distlib.metadata import Metadata
+from pip._vendor.packaging.markers import Marker
+from pip._vendor.packaging.requirements import Requirement as PackagingRequirement
+from pip._vendor.packaging.specifiers import Specifier, SpecifierSet
+from pip._vendor.packaging.tags import Tag
+from pip._vendor.packaging.version import _BaseVersion, parse
 
 from ..environment import MYPY_RUNNING
 from .markers import (
@@ -48,7 +46,6 @@ if MYPY_RUNNING:
         Any,
         Callable,
         Dict,
-        Generator,
         Generic,
         Iterator,
         List,
@@ -138,7 +135,7 @@ def validate_digest(inst, attrib, value):
 
 
 def get_local_wheel_metadata(wheel_file):
-    # type: (str) -> Optional[distlib.metadata.Metadata]
+    # type: (str) -> Optional[Metadata]
     parsed_metadata = None
     with io.open(wheel_file, "rb") as fh:
         with zipfile.ZipFile(fh, mode="r", compression=zipfile.ZIP_DEFLATED) as zf:
@@ -150,7 +147,7 @@ def get_local_wheel_metadata(wheel_file):
             if metadata is None:
                 raise RuntimeError("No metadata found in wheel: {0}".format(wheel_file))
             with zf.open(metadata, "r") as metadata_fh:
-                parsed_metadata = distlib.metadata.Metadata(fileobj=metadata_fh)
+                parsed_metadata = Metadata(fileobj=metadata_fh)
     return parsed_metadata
 
 
@@ -166,7 +163,7 @@ def get_remote_sdist_metadata(line):
 
 
 def get_remote_wheel_metadata(whl_file):
-    # type: (str) -> Optional[distlib.metadata.Metadata]
+    # type: (str) -> Optional[Metadata]
     parsed_metadata = None
     data = io.BytesIO()
     with vistir.contextmanagers.open_file(whl_file) as fp:
@@ -181,7 +178,7 @@ def get_remote_wheel_metadata(whl_file):
         if metadata is None:
             raise RuntimeError("No metadata found in wheel: {0}".format(whl_file))
         with zf.open(metadata, "r") as metadata_fh:
-            parsed_metadata = distlib.metadata.Metadata(fileobj=metadata_fh)
+            parsed_metadata = Metadata(fileobj=metadata_fh)
     return parsed_metadata
 
 
@@ -259,11 +256,11 @@ class Dependency(object):
                 markers = [marker_from_specifier(str(s)) for s in specifiers]
             py_version_part = reduce(merge_markers, markers)
         if self.markers:
-            line_str = "{0}; {1}".format(line_str, str(self.markers))
+            line_str = "{0} ; {1}".format(line_str, str(self.markers))
             if py_version_part:
                 line_str = "{0} and {1}".format(line_str, py_version_part)
         elif py_version_part and not self.markers:
-            line_str = "{0}; {1}".format(line_str, py_version_part)
+            line_str = "{0} ; {1}".format(line_str, py_version_part)
         return line_str
 
     def pin(self):
@@ -351,7 +348,7 @@ class Dependency(object):
                     marker_str = "{0!s}".format(marker)
         req_str = "{0}=={1}".format(info.name, info.version)
         if marker_str:
-            req_str = "{0}; {1}".format(req_str, marker_str)
+            req_str = "{0} ; {1}".format(req_str, marker_str)
         req = PackagingRequirement(req_str)
         requires_python_str = (
             info.requires_python if info.requires_python is not None else ""
@@ -501,12 +498,17 @@ class ReleaseUrl(object):
     #: The upload timestamp from the package
     upload_time = attr.ib(
         type=datetime.datetime,
-        converter=instance_check_converter(datetime.datetime, dateutil.parser.parse),  # type: ignore
+        converter=instance_check_converter(
+            datetime.datetime, datetime.datetime.fromisoformat
+        ),  # type: ignore
     )
     #: The ISO8601 formatted upload timestamp of the package
     upload_time_iso_8601 = attr.ib(
         type=datetime.datetime,
-        converter=instance_check_converter(datetime.datetime, dateutil.parser.parse),  # type: ignore
+        converter=instance_check_converter(
+            datetime.datetime,
+            lambda t_str: datetime.datetime.strptime(t_str, "%Y-%m-%dT%H:%M:%S.%fZ"),
+        ),  # type: ignore
     )
     #: The size in bytes of the package
     size = attr.ib(type=int)
@@ -566,7 +568,7 @@ class ReleaseUrl(object):
         markers = self.markers
         req_str = "{0} @ {1}#egg={0}".format(self.name, self.url)
         if markers:
-            req_str = "{0}; {1}".format(req_str, markers)
+            req_str = "{0} ; {1}".format(req_str, markers)
         return req_str
 
     def get_markers_from_wheel(self):
@@ -640,7 +642,7 @@ class ReleaseUrl(object):
         release_url = cls(**filter_dict(creation_kwargs))  # type: ignore
         if release_url.is_wheel:
             supported_tags = [
-                parse_tag(Tag(*tag)) for tag in distlib.wheel.Wheel(release_url.url).tags
+                parse_tag(Tag(*tag)) for tag in wheel.Wheel(release_url.url).tags
             ]
             release_url = attr.evolve(release_url, tags=supported_tags)
         return release_url
@@ -776,8 +778,8 @@ class Release(Sequence):
 
     @property
     def parsed_version(self):
-        # type: () -> packaging.version._BaseVersion
-        return packaging.version.parse(self.version)
+        # type: () -> _BaseVersion
+        return parse(self.version)
 
     @property
     def wheels(self):
@@ -854,8 +856,8 @@ class ReleaseCollection(object):
     def wheels(self):
         # type: () -> Iterator[ReleaseUrl]
         for release in self.sort_releases():
-            for wheel in release.wheels:
-                yield wheel
+            for w in release.wheels:
+                yield w
 
     def sdists(self):
         # type: () -> Iterator[ReleaseUrl]
@@ -1056,8 +1058,8 @@ class Package(object):
     @property
     def latest_wheels(self):
         # type: () -> Iterator[ReleaseUrl]
-        for wheel in self.urls.wheels:
-            yield wheel
+        for w in self.urls.wheels:
+            yield w
 
     @property
     def dependencies(self):
