@@ -12,7 +12,7 @@ from pip._internal.models.target_python import TargetPython
 from pip._internal.utils.filetypes import is_archive_file
 from pip._internal.utils.misc import is_installable_dir
 from pip._vendor.packaging import specifiers
-from vistir.path import ensure_mkdir_p, is_valid_url
+from vistir.path import is_valid_url
 
 from .environment import MYPY_RUNNING
 
@@ -292,11 +292,6 @@ def get_package_finder(
     )
 
 
-@ensure_mkdir_p(mode=0o777)
-def _ensure_dir(path):
-    return path
-
-
 _UNSET = object()
 _REMAP_EXIT = object()
 
